# coding: utf-8

from __future__ import annotations

import re  # noqa: F401
from datetime import date, datetime  # noqa: F401
from typing import Any, Dict, List, Optional  # noqa: F401

from fastapi_camelcase import CamelModel  # noqa: F401
from pydantic import AnyUrl, Field

from telus_bulk.models.tmf_645.related_party import RelatedParty
from telus_bulk.models.tmf_645.task_state_type import TaskStateType


class ServiceQualification(CamelModel):
    """NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).

    Do not edit the class manually.

    ServiceQualification - a model defined in OpenAPI

        id: The id of this ServiceQualification [Optional].
        href: The href of this ServiceQualification [Optional].
        description: The description of this ServiceQualification [Optional].
        effective_qualification_date: The effective_qualification_date of this ServiceQualification [Optional].
        estimated_response_date: The estimated_response_date of this ServiceQualification [Optional].
        expected_qualification_date: The expected_qualification_date of this ServiceQualification [Optional].
        expiration_date: The expiration_date of this ServiceQualification [Optional].
        external_id: The external_id of this ServiceQualification [Optional].
        instant_sync_qualification: The instant_sync_qualification of this ServiceQualification [Optional].
        related_party: The related_party of this ServiceQualification [Optional].
        state: The state of this ServiceQualification [Optional].
        base_type: The base_type of this ServiceQualification [Optional].
        schema_location: The schema_location of this ServiceQualification [Optional].
        type: The type of this ServiceQualification [Optional].
    """

    id: Optional[str] = None
    href: Optional[str] = None
    description: Optional[str] = None
    effective_qualification_date: Optional[datetime] = None
    estimated_response_date: Optional[datetime] = None
    expected_qualification_date: Optional[datetime] = None
    expiration_date: Optional[datetime] = None
    external_id: Optional[str] = None
    instant_sync_qualification: Optional[bool] = None
    related_party: Optional[List[RelatedParty]] = None
    state: Optional[TaskStateType] = None
    base_type: Optional[str] = None
    schema_location: Optional[AnyUrl] = None
    type: Optional[str] = Field(default=None, alias="@type")


ServiceQualification.update_forward_refs()



from __future__ import annotations

from typing import Optional, Literal

from fastapi_camelcase import CamelModel
from pydantic import Field
from telus_bulk.models.ams.coordinate import Coordinate


class Place(CamelModel):
    id: str
    role: Optional[str] = None
    _type: str = Field(alias="@type", default="GeographicAddress")


class PlaceAMS(Place):
    city: Optional[str] = None
    country: Literal["USA", "CAN"] = "CAN"
    postcode: Optional[str] = None
    state_or_province: Optional[str] = None
    street_dir: Optional[str] = None
    street_name: Optional[str] = None
    street_nr: Optional[str] = None
    street_type: Optional[str] = None
    floor: Optional[str] = None
    unit: Optional[str] = None
    address_type: Optional[str] = None
    coordinate: Optional[Coordinate] = None



from __future__ import annotations

from typing import Union, Optional, List

from fastapi_camelcase import CamelModel
from telus_bulk.models.tmf_645.characteristic import Characteristic
from telus_bulk.models.worker_job.place import Place, PlaceAMS
from telus_bulk.models.worker_job.service_specification import ServiceSpecification
from telus_bulk.models.product_type import ProductType


class AddressProcessingJob(CamelModel):
    csq_id: str
    instant_sync_qualification: bool
    provide_alternative: bool
    place: Union[PlaceAMS, Place]
    service_specification: ServiceSpecification
    service_characteristic: Optional[List[Characteristic]] = None

    def get_product_type(self):
        default_type = ProductType.nhp
        if self.service_specification is None:
            return default_type
        if self.service_specification.name == (
            "Off_Net_Unmanaged" or "off_net_unmanaged"
        ):
            return ProductType.nhp
        elif self.service_specification.name == (
            "Off_Net_Managed" or "off_net_managed"
        ):
            return ProductType.fib
        return default_type



# coding: utf-8

from __future__ import annotations

import re  # noqa: F401
from datetime import datetime  # noqa: F401
from typing import List, Optional  # noqa: F401

from fastapi_camelcase import CamelModel
from pydantic import AnyUrl, Field  # noqa: F401

from telus_bulk.models.tmf_645.alternate_service_proposal import (
    AlternateServiceProposal,
)
from telus_bulk.models.tmf_645.service_category_ref import ServiceCategoryRef
from telus_bulk.models.tmf_645.service_eligibility_unavailability_reason import (
    ServiceEligibilityUnavailabilityReason,
)
from telus_bulk.models.tmf_645.service_qualification_item_relationship import (
    ServiceQualificationItemRelationship,
)
from telus_bulk.models.tmf_645.service_qualification_relationship import (
    ServiceQualificationRelationship,
)
from telus_bulk.models.tmf_645.service_ref_or_value import ServiceRefOrValue
from telus_bulk.models.tmf_645.termination_error import TerminationError


class CheckServiceQualificationItem(CamelModel):
    """NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).

    Do not edit the class manually.

    CheckServiceQualificationItem - a model defined in OpenAPI

        id: The id of this CheckServiceQualificationItem [Optional].
        expected_activation_date: The expected_activation_date of this CheckServiceQualificationItem [Optional].
        expected_service_availability_date: The expected_service_availability_date of this CheckServiceQualificationItem [Optional].
        expiration_date: The expiration_date of this CheckServiceQualificationItem [Optional].
        qualification_result: The qualification_result of this CheckServiceQualificationItem [Optional].
        state: The state of this CheckServiceQualificationItem [Optional].
        alternate_service_proposal: The alternate_service_proposal of this CheckServiceQualificationItem [Optional].
        category: The category of this CheckServiceQualificationItem [Optional].
        eligibility_unavailability_reason: The eligibility_unavailability_reason of this CheckServiceQualificationItem [Optional].
        qualification_item_relationship: The qualification_item_relationship of this CheckServiceQualificationItem [Optional].
        qualification_relationship: The qualification_relationship of this CheckServiceQualificationItem [Optional].
        service: The service of this CheckServiceQualificationItem [Optional].
        termination_error: The termination_error of this CheckServiceQualificationItem [Optional].
        base_type: The base_type of this CheckServiceQualificationItem [Optional].
        schema_location: The schema_location of this CheckServiceQualificationItem [Optional].
        type: The type of this CheckServiceQualificationItem [Optional].
    """

    id: Optional[str] = None
    expected_activation_date: Optional[datetime] = None
    expected_service_availability_date: Optional[datetime] = None
    expiration_date: Optional[datetime] = None
    qualification_result: Optional[str] = None
    state: Optional[str] = None
    alternate_service_proposal: Optional[List[AlternateServiceProposal]] = None
    category: Optional[ServiceCategoryRef] = None
    eligibility_unavailability_reason: Optional[
        List[ServiceEligibilityUnavailabilityReason]
    ] = None
    qualification_item_relationship: Optional[
        List[ServiceQualificationItemRelationship]
    ] = None
    qualification_relationship: Optional[List[ServiceQualificationRelationship]] = None
    service: Optional[ServiceRefOrValue] = None
    termination_error: Optional[List[TerminationError]] = None
    base_type: Optional[str] = None
    schema_location: Optional[AnyUrl] = None
    type: Optional[str] = Field(default=None, alias="@type")


CheckServiceQualificationItem.update_forward_refs()



# coding: utf-8

from __future__ import annotations

import re  # noqa: F401
from datetime import date, datetime  # noqa: F401
from typing import Any, Dict, List, Optional  # noqa: F401

from fastapi_camelcase import CamelModel  # noqa: F401


class TaskStateType(CamelModel):
    """NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).

    Do not edit the class manually.

    TaskStateType - a model defined in OpenAPI

    """


TaskStateType.update_forward_refs()



# coding: utf-8

from __future__ import annotations

import re  # noqa: F401
from datetime import date, datetime  # noqa: F401
from typing import Any, Dict, List, Optional  # noqa: F401

from fastapi_camelcase import CamelModel  # noqa: F401
from pydantic import AnyUrl, Field


class TerminationError(CamelModel):
    """NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).

    Do not edit the class manually.

    TerminationError - a model defined in OpenAPI

        id: The id of this TerminationError [Optional].
        value: The value of this TerminationError [Optional].
        base_type: The base_type of this TerminationError [Optional].
        schema_location: The schema_location of this TerminationError [Optional].
        type: The type of this TerminationError [Optional].
    """

    id: Optional[str] = None
    value: Optional[str] = None
    base_type: Optional[str] = None
    schema_location: Optional[AnyUrl] = None
    type: Optional[str] = Field(default=None, alias='@type')


TerminationError.update_forward_refs()
